/*
GLDM - Graphical Liberty Display Manager

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software Foundation,
Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/

#ifndef UNIXAUTHPROVIDER_H_INCLUDED
#define UNIXAUTHPROVIDER_H_INCLUDED

#include "authprovider.h"
#include "user.h"

/** This class provides a basic auth provider for UNIXes using
  * shadow storage for passwords.
  */
class UnixAuthProvider : public AuthProvider
{
    public:
    /** Initializes the auth provider
      */
    UnixAuthProvider();

    /** Returns true if password is valid
      */
    bool checkOwnAuth(const std::string& login, const std::string& password);

    /** Loads list of users from /etc/passwd into member variable
      */
    void loadUsers(int minUID = 1000, int maxUID = 32767, const char* passwd = "/etc/passwd");

    /** Gets list of users from previously loaded /etc/passwd stored in mUsers
      */
    std::vector<std::string> getOwnLoginListUsers();

    /** \todo document me!
      */
    std::string getOwnDisplayName(std::string username);

    /** \todo document me!
      */
    std::string getOwnHomeDir(std::string username);

    private:
    std::vector<User> mUsers;

};

#endif
